@@ -1,6 +1,7 @@
 """ARRL plugin"""
 
 # pylint: disable=invalid-name, unused-argument, unused-variable, c-extension-no-member, unused-import
+# pylint: disable=logging-fstring-interpolation
 
 import datetime
 import logging
@@ -24,7 +25,7 @@ columns = [
     "Freq",
     "Snt",
     "Rcv",
-    "Power",
+    "RcvNr",
     "M1",
     "PFX",
     "PTS",
@@ -95,7 +96,6 @@ def set_contact_vars(self):
     """Contest Specific"""
     self.contact["SNT"] = self.sent.text()
     self.contact["RCV"] = self.receive.text()
-    self.contact["Power"] = self.other_2.text().upper()
     self.contact["NR"] = self.other_2.text().upper()
     self.contact["SentNr"] = self.contest_settings.get("SentExchange", 0)
 
@@ -110,19 +110,33 @@ def prefill(self):
     #     self.other_2.setText(str(self.contact.get("ZN", "")))
     self.other_1.setText(str(self.contest_settings.get("SentExchange", 0)))
 
+    location = self.cty_lookup(self.station.get("Call", ""))
+    if location:
+        for item in location.items():
+            mycountry = item[1].get("primary_pfx", "")
+            if mycountry in ["K", "VE"]:
+                query = f"select count(*) as prefix_count from dxlog where Band={float(self.contact.get('Band', 0))} and CountryPrefix='{self.contact.get('CountryPrefix','')}' and ContestNR = {self.pref.get('contest', '1')} and points = 3;"
+            else:
+                query = f"select count(*) as prefix_count from dxlog where Band={float(self.contact.get('Band', 0))} and NR='{self.contact.get('NR','')}' and ContestNR = {self.pref.get('contest', '1')} and points = 3;"
+
+    result = self.database.exec_sql(query)
+    count = result.get("prefix_count", 0)
+    if count == 0:
+        self.contact["IsMultiplier1"] = 1
+    else:
+        self.contact["IsMultiplier1"] = 0
+
 
 def points(self):
     """Calc point"""
     result = self.cty_lookup(self.station.get("Call", ""))
     if result:
         for item in result.items():
-            mycountry = item[1].get("entity", "")
-            # mycontinent = item[1].get("continent", "")
+            mycountry = item[1].get("primary_pfx", "")
     result = self.cty_lookup(self.contact.get("Call", ""))
     if result:
         for item in result.items():
-            entity = item[1].get("entity", "")
-            # continent = item[1].get("continent", "")
+            entity = item[1].get("primary_pfx", "")
             if mycountry in ["K", "VE"]:
                 if entity in ["K", "VE"]:
                     return 0
@@ -135,9 +149,18 @@ def points(self):
 
 def show_mults(self):
     """Return display string for mults"""
-    result = self.database.fetch_arrldx_country_band_count()
-    if result:
-        return int(result.get("cb_count", 0))
+    location = self.cty_lookup(self.station.get("Call", ""))
+    if location:
+        for item in location.items():
+            mycountry = item[1].get("primary_pfx", "")
+            if mycountry in ["K", "VE"]:
+                result = self.database.fetch_arrldx_country_band_count()
+                if result:
+                    return int(result.get("cb_count", 0))
+            else:
+                result = self.database.fetch_arrldx_state_prov_count()
+                if result:
+                    return int(result.get("cb_count", 0))
     return 0
 
 
@@ -345,13 +368,27 @@ def recalculate_mults(self):
     for contact in all_contacts:
         time_stamp = contact.get("TS", "")
         entity = contact.get("CountryPrefix", "")
-        query = (
-            f"select count(*) as prefix_count from dxlog where  TS < '{time_stamp}' "
-            f"and CountryPrefix = '{entity}' "
-            f"and ContestNR = {self.pref.get('contest', '1')};"
-        )
+        location = self.cty_lookup(self.station.get("Call", ""))
+        if location:
+            for item in location.items():
+                mycountry = item[1].get("primary_pfx", "")
+                if mycountry in ["K", "VE"]:
+                    query = (
+                        f"select count(*) as prefix_count from dxlog where TS < '{time_stamp}' "
+                        f"and CountryPrefix='{contact.get('CountryPrefix','')}' "
+                        f"and ContestNR = {self.pref.get('contest', '1')} and points = 3;"
+                    )
+                else:
+                    query = (
+                        f"select count(*) as prefix_count from dxlog where TS < '{time_stamp}' "
+                        f"and NR='{contact.get('NR','')}' "
+                        f"and ContestNR = {self.pref.get('contest', '1')} and points = 3;"
+                    )
         result = self.database.exec_sql(query)
-        count = result.get("prefix_count", 1)
+        logger.debug("contact: %s", contact)
+        logger.debug("query: %s", query)
+        logger.debug("result: %s", result)
+        count = int(result.get("prefix_count", 1))
         if count == 0 and contact.get("Points", 0) == 3:
             contact["IsMultiplier1"] = 1
         else:
